@@ -1,43 +1,40 @@
 /****************************************************************************
 **
-** Copyright (C) 2005-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
+** All rights reserved.
+** Contact: Nokia Corporation (qt-info@nokia.com)
 **
-** This file is part of the example classes of the Qt Toolkit.
+** This file is part of the examples of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** $QT_BEGIN_LICENSE:BSD$
+** You may use this file under the terms of the BSD license as follows:
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
+** "Redistribution and use in source and binary forms, with or without
+** modification, are permitted provided that the following conditions are
+** met:
+**   * Redistributions of source code must retain the above copyright
+**     notice, this list of conditions and the following disclaimer.
+**   * Redistributions in binary form must reproduce the above copyright
+**     notice, this list of conditions and the following disclaimer in
+**     the documentation and/or other materials provided with the
+**     distribution.
+**   * Neither the name of Nokia Corporation and its Subsidiary(-ies) nor
+**     the names of its contributors may be used to endorse or promote
+**     products derived from this software without specific prior written
+**     permission.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
-**
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
-**
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+** "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+** LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
+** A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
+** OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
+** SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
+** LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
+** DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
+** THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+** (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
+** OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE."
+** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
@@ -45,6 +42,7 @@
 
 #include "renderarea.h"
 
+//! [0]
 RenderArea::RenderArea(QWidget *parent)
     : QWidget(parent)
 {
@@ -56,47 +54,63 @@ RenderArea::RenderArea(QWidget *parent)
     setBackgroundRole(QPalette::Base);
     setAutoFillBackground(true);
 }
+//! [0]
 
+//! [1]
 QSize RenderArea::minimumSizeHint() const
 {
     return QSize(100, 100);
 }
+//! [1]
 
+//! [2]
 QSize RenderArea::sizeHint() const
 {
     return QSize(400, 200);
 }
+//! [2]
 
+//! [3]
 void RenderArea::setShape(Shape shape)
 {
     this->shape = shape;
     update();
 }
+//! [3]
 
+//! [4]
 void RenderArea::setPen(const QPen &pen)
 {
     this->pen = pen;
     update();
 }
+//! [4]
 
+//! [5]
 void RenderArea::setBrush(const QBrush &brush)
 {
     this->brush = brush;
     update();
 }
+//! [5]
 
+//! [6]
 void RenderArea::setAntialiased(bool antialiased)
 {
     this->antialiased = antialiased;
     update();
 }
+//! [6]
 
+//! [7]
 void RenderArea::setTransformed(bool transformed)
 {
     this->transformed = transformed;
     update();
 }
+//! [7]
 
+//! [8]
 void RenderArea::paintEvent(QPaintEvent * /* event */)
 {
     static const QPoint points[4] = {
@@ -113,28 +127,33 @@ void RenderArea::paintEvent(QPaintEvent * /* event */)
     path.lineTo(20, 30);
     path.cubicTo(80, 0, 50, 50, 80, 80);
 
-    int startAngle = 30 * 16;
+    int startAngle = 20 * 16;
     int arcLength = 120 * 16;
+//! [8]
 
+//! [9]
     QPainter painter(this);
     painter.setPen(pen);
     painter.setBrush(brush);
-    if (antialiased) {
+    if (antialiased)
         painter.setRenderHint(QPainter::Antialiasing, true);
-        painter.translate(+0.5, +0.5);
-    }
+//! [9]
 
+//! [10]
     for (int x = 0; x < width(); x += 100) {
         for (int y = 0; y < height(); y += 100) {
             painter.save();
             painter.translate(x, y);
+//! [10] //! [11]
             if (transformed) {
                 painter.translate(50, 50);
                 painter.rotate(60.0);
                 painter.scale(0.6, 0.9);
                 painter.translate(-50, -50);
             }
+//! [11]
 
+//! [12]
             switch (shape) {
             case Line:
                 painter.drawLine(rect.bottomLeft(), rect.topRight());
@@ -151,8 +170,8 @@ void RenderArea::paintEvent(QPaintEvent * /* event */)
             case Rect:
                 painter.drawRect(rect);
                 break;
-            case RoundRect:
-                painter.drawRoundRect(rect);
+            case RoundedRect:
+                painter.drawRoundedRect(rect, 25, 25, Qt::RelativeSize);
                 break;
             case Ellipse:
                 painter.drawEllipse(rect);
@@ -170,16 +189,19 @@ void RenderArea::paintEvent(QPaintEvent * /* event */)
                 painter.drawPath(path);
                 break;
             case Text:
-                painter.drawText(rect, Qt::AlignCenter, tr("Qt by\nTrolltech"));
+                painter.drawText(rect, Qt::AlignCenter, tr("Qt by\nNokia"));
                 break;
             case Pixmap:
                 painter.drawPixmap(10, 10, pixmap);
             }
+//! [12] //! [13]
             painter.restore();
         }
     }
 
+    painter.setRenderHint(QPainter::Antialiasing, false);
     painter.setPen(palette().dark().color());
     painter.setBrush(Qt::NoBrush);
     painter.drawRect(QRect(0, 0, width() - 1, height() - 1));
 }
+//! [13]
